#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*******************************************************************************
#**  This file is part of HgWeb Manager.                                     ***
#**                                                                          ***
#**  Copyright (C) 2014                                                      ***
#**  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Affero General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Affero General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Affero General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************

# The current version of the application
VERSION = "0.1.0"
# The current copyright years.
YEARS = "2014"

"""
 IMPORTS
"""
import configuration as config
import argparse
import manager
import repository


def is_hgWeb_user(userName):
	"""Determines if the current running user is the expected HgWeb user.

	 @return Gives true when the user is the expected HgWeb user, false
	  else-wise.
	"""
	import getpass

	# FIXME: This isn't a secure check as it is based upon the environmental variable.
	if userName == getpass.getuser():
		return True
	else:
		return False


def main(args):
	settings = config.Manager()
	if not is_hgWeb_user(settings.HgUser):
		print >>sys.stderr, "Must execute as the Mercurial Web manager."
		exit(1)

	parser = argparse.ArgumentParser(description='Manages HgWeb Repositories')
	parser.add_argument("create", action="store", nargs='+', help='Creates a new HgWeb repository.')
	parser.add_argument("repository", action="store", nargs=1, help='The storage-name for the repository.')
	parser.add_argument("-n", "--name", action="store", nargs=1, help='The display name for the repository.')
	parser.add_argument("-d", "--description", action="store", nargs=1, default="", help='The description for the repository.')
	parser.add_argument("-c", "--contact", action="store", nargs=1, default="", help='The contact point for a repository.')
	args = parser.parse_args()
	repo = repository.extract_values(args)

	if args.create:
		if manager.create(settings, repo):
			print "Success creating repository %s." % repo.StorageName
		else:
			print "Failure creating repository %s." % repo.StorageName

	exit(0)

if __name__ == "__main__":
	import sys

	# Display license
	print "HWM %s Copyright (C) %s CodeGNU Solutions" % (VERSION, YEARS)
	print "HWM comes with ABSOLUTELY NO WARRANTY;"
	print "This is free software, and you are welcome to redistribute it"
	print "under certain conditions; see the LICENSE file for details,"
	print "or the Free Software Foundation's AGPL.\n"

	main(sys.argv)
