#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*******************************************************************************
#**  This file is part of HgWeb Manager.                                     ***
#**                                                                          ***
#**  Copyright (C) 2014                                                      ***
#**  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Affero General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Affero General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Affero General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************

class Repository(object):
	# The directory name of the managed repository.
	__storageName = None
	# The displayed web-site name of the managed repository.
	__displayName = None
	# The displayed web-site description of the managed repository.
	__description = None
	# The displayed web-site contact information of the managed repository.
	__contact = None

	@property
	def StorageName(self):
		""" Gets the name of the directory where the managed repository is located. """
		return self.__storageName
	@StorageName.setter
	def StorageName(self, value):
		""" Sets the name of the directory with a supplied name. """
		self.__storageName = value

	@property
	def DisplayName(self):
		""" Gets the name to display for the managed repository. """
		return self.__displayName
	@DisplayName.setter
	def DisplayName(self, value):
		""" Sets the name of the managed repository to display. """
		self.__displayName = value

	@property
	def Description(self):
		""" Gets the description of the managed repository. """
		return self.__description
	@Description.setter
	def Description(self, value):
		""" Sets the description of the managed repository to display. """
		self.__description = value

	@property
	def Contact(self):
		""" Gets the contact point for the managed repository. """
		return self.__contact
	@Contact.setter
	def Contact(self, value):
		""" Sets the contact point for the managed repository. """
		self.__contact = value

	def __init__(self):
		""" Initialises the object with default values. """
		self.__storageName = None
		self.__displayName = None
		self.__description = None
		self.__contact = None

def extract_values(args):
	"""Pulls the creation arguments out of the command-line.

	 @param[in] args	The command-line argument processor containing the
					creation argument values.

	 @return A managed repository object.
	"""
	managed = Repository()
	if args.repository:
		managed.StorageName = args.repository[0]

	if args.name:
		managed.DisplayName = args.name[0]

	if args.description:
		managed.Description = args.description[0]

	if args.contact:
		managed.Contact = args.contact[0]
	return managed

